<!DOCTYPE html>
<html lang="en">
    <meta charset="utf-8">
    <title>REST API</title>
<head>

<link rel="shortcut icon" href="{{ STATIC_URL }}img/favicon.png"/>

<link href="{{ STATIC_URL }}css/bootstrap-combined.min.css" rel="stylesheet">
<link href="{{ STATIC_URL }}css/docs.css" rel="stylesheet">
<link href="{{ STATIC_URL }}css/zenburn.min.css" rel="stylesheet">

<script src="{{ STATIC_URL }}js/jquery-1.9.1.min.js"></script>
<script src="{{ STATIC_URL }}js/jquery-migrate-1.2.0.min.js"></script>
<script src="{{ STATIC_URL }}js/jquery-ui-1.8.custom.min.js"></script>
<script src="{{ STATIC_URL }}js/jquery.mousewheel.js"></script>
<script src="{{ STATIC_URL }}js/bootstrap.min.js"></script>
<script src="{{ STATIC_URL }}js/raphael.min.js"></script>
<script src="{{ STATIC_URL }}js/jquery.base64.js"></script>
<script src="{{ STATIC_URL }}js/markdown.min.js"></script>
<script src="{{ STATIC_URL }}js/vkbeautify.js"></script>
<script src="{{ STATIC_URL }}js/canvasmol.js"></script>
<script src="{{ STATIC_URL }}js/ZeroClipboard.js"></script>
<script src="{{ STATIC_URL }}js/spore.js"></script>
<script src="{{ STATIC_URL }}js/highlight.min.js"></script>
<script type="text/javascript">
var api;
$(function() {
   spore.debug(false);
   spore.create('{% url 'ws_spore_endpoint' %}',function(a){api=a;},'','servicelist');
   ZeroClipboard.config({swfPath: '{{ STATIC_URL }}swf/ZeroClipboard.swf'} );
});

function ClipboardCopyInit(control, text) {
    var client = new ZeroClipboard(control);
    var status = $('.clipboardStatus', $(control).closest('.restapiholderresponse'));
    client.on("ready", function(rev){
        client.on( 'copy', function(ev) {
            ev.clipboardData.setData('text/plain', text);
            if (status) {
                status.text('copied');
                status.show();
                status.fadeOut(2000);
            }
        });
    });
}

</script>
</head>
<body>
        {% include "head_banner.html" %}
        <div class="offset1" id="servicelist"></div>
</body>
</html>